@@ -50,6 +50,7 @@ class OppoDevice:
     self._client = client
     self._mac_address = mac_address
     self._client.add_event_handler(EVENT_MESSAGE_RECEIVED, self._on_message_received)
+    self._client.add_event_handler(EVENT_CONNECTED, self._on_client_connected)
     self._client.add_event_handler(EVENT_DISCONNECTED, self._on_client_disconnected)
 
     self.power_status = PowerStatus.DISCONNECTED
@@ -78,7 +79,20 @@ class OppoDevice:
   @property
   def cddb_id(self) -> str:
     """The disc id for the currently loaded disc"""
-    return self.cddb_id_1 + self.cddb_id_2
+    return self._cddb_id
+
+  @property
+  def cddb_id_2(self) -> str:
+    return self._cddb_id_2
+  
+  @cddb_id_2.setter
+  def cddb_id_2(self, value: str):
+    self._cddb_id_2 = value
+    if self.cddb_id_1 + self._cddb_id_2 != self._cddb_id:
+      #set the full id
+      self._cddb_id = self.cddb_id_1 + self._cddb_id_2
+      #call the async event to indicate the change
+      self._client.loop.create_task(self._client.async_event(EVENT_DISC_ID_CHANGED, self))
 
   @property
   def is_updating(self) -> bool:
@@ -92,7 +106,7 @@ class OppoDevice:
         #disable individual state events since we're doing a bunch at once
       self._state_events_enabled = False
       await self._client.async_event(EVENT_DEVICE_STATE_UPDATING, self)
-      #await self._client.async_send_command(OppoSetVerboseModeCommand(SetVerboseMode.OFF))
+      await self._client.async_send_command(OppoSetVerboseModeCommand(SetVerboseMode.VERBOSE))
       await self._client.async_send_command(OppoQueryCommand(OppoQueryCode.QVM))
       await self._client.async_send_command(OppoQueryCommand(OppoQueryCode.QPW))
       await self._client.async_send_command(OppoQueryCommand(OppoQueryCode.QVR))
@@ -109,14 +123,13 @@ class OppoDevice:
       await self._client.async_send_command(OppoQueryCdCommand())
 
       #request media-related updates
-      await self.async_request_media_update(False)
+      await self.async_request_media_update(False, True)
     finally:
       #re-enable state events and send the updated event
-      #await self._client.async_send_command(OppoSetVerboseModeCommand(SetVerboseMode.VERBOSE))
       self._state_events_enabled = True
       await self._client.async_event(EVENT_DEVICE_STATE_UPDATED, self)
 
-  async def async_request_media_update(self, suspend_events: bool = True):
+  async def async_request_media_update(self, suspend_events: bool = True, full_update: bool = False):
     try:
       if self.is_playing:
         if suspend_events:
@@ -131,17 +144,20 @@ class OppoDevice:
         await self._client.async_send_command(OppoQueryCommand(OppoQueryCode.QCR))
         await self._client.async_send_command(OppoQueryCommand(OppoQueryCode.QEL))
         await self._client.async_send_command(OppoQueryCommand(OppoQueryCode.QRE))
-        await self._client.async_send_command(OppoQueryCommand(OppoQueryCode.QAT))
-        await self._client.async_send_command(OppoQueryCommand(OppoQueryCode.QST))
-        await self._client.async_send_command(OppoQueryCommand(OppoQueryCode.QRP))   
-        await self._client.async_send_command(OppoQueryCommand(OppoQueryCode.Q3D))
-        await self._client.async_send_command(OppoQueryCommand(OppoQueryCode.QHS))   
-        await self._client.async_send_command(OppoQueryCommand(OppoQueryCode.QFT))
-        await self._client.async_send_command(OppoQueryCommand(OppoQueryCode.QFN))
-        await self._client.async_send_command(OppoQueryCommand(OppoQueryCode.QTN))
-        await self._client.async_send_command(OppoQueryCommand(OppoQueryCode.QTA))
-        await self._client.async_send_command(OppoQueryCommand(OppoQueryCode.QTP))
-        await self._client.async_send_command(OppoQueryCommand(OppoQueryCode.QDS))
+
+        if full_update:
+          await self._client.async_send_command(OppoQueryCommand(OppoQueryCode.QAT))
+          await self._client.async_send_command(OppoQueryCommand(OppoQueryCode.QST))
+          await self._client.async_send_command(OppoQueryCommand(OppoQueryCode.QRP))   
+          await self._client.async_send_command(OppoQueryCommand(OppoQueryCode.Q3D))
+          await self._client.async_send_command(OppoQueryCommand(OppoQueryCode.QHS))   
+          await self._client.async_send_command(OppoQueryCommand(OppoQueryCode.QFT))
+          await self._client.async_send_command(OppoQueryCommand(OppoQueryCode.QFN))
+          await self._client.async_send_command(OppoQueryCommand(OppoQueryCode.QTN))
+          await self._client.async_send_command(OppoQueryCommand(OppoQueryCode.QTA))
+          await self._client.async_send_command(OppoQueryCommand(OppoQueryCode.QTP))
+          await self._client.async_send_command(OppoQueryCommand(OppoQueryCode.QDS))
+          
         self._calculate_duration()
     finally:
       if suspend_events:
@@ -154,7 +170,6 @@ class OppoDevice:
       #async with self._update_lock:      
       self._state_events_enabled = False
       await self._client.async_event(EVENT_DEVICE_STATE_UPDATING, self)
-      #await self._client.async_send_command(OppoSetVerboseModeCommand(SetVerboseMode.OFF))
       await self._client.async_send_command(OppoQueryCommand(OppoQueryCode.QTK))
       await self._client.async_send_command(OppoQueryCommand(OppoQueryCode.QCH))
       await self._client.async_send_command(OppoQueryCommand(OppoQueryCode.QTE))
@@ -166,7 +181,6 @@ class OppoDevice:
       self._calculate_duration()
       
     finally:
-      #await self._client.async_send_command(OppoSetVerboseModeCommand(SetVerboseMode.VERBOSE))
       self._state_events_enabled = True
       await self._client.async_event(EVENT_DEVICE_STATE_UPDATED, self)
 
@@ -206,6 +220,7 @@ class OppoDevice:
     self.hdr_setting = HdrSetting.UNKNOWN
     self.disc_type = DiscType.UNKNOWN
     self.playback_status = PlayStatus.OFF
+    self._cddb_id = ""
     self.cddb_id_1 = ""
     self.cddb_id_2 = ""
     self.last_update_at = datetime.utcnow()
@@ -219,6 +234,10 @@ class OppoDevice:
     pa.chapter_duration = pa.chapter_elapsed_time + pa.chapter_remaining_time
     pa.total_duration = pa.total_elapsed_time + pa.total_remaining_time
 
+  async def _on_client_connected(self):
+    """Handles the client connected event"""
+    self.power_status = PowerStatus.UNKNOWN
+
   async def _on_client_disconnected(self):
     """Handles the client disconnected event"""
     self.power_status = PowerStatus.DISCONNECTED
